package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.CarouselImagesClient;
import com.chelvc.cloud.vehicle.client.dto.CarouselImagesDTO;
import com.chelvc.cloud.vehicle.client.param.CarouselImagesModifyParam;
import com.chelvc.cloud.vehicle.client.param.CarouselImagesPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 轮播图接口
 *
 * @author liude
 * @Date 2023/12/29
 **/
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CarouselImagesController {
    private final CarouselImagesClient carouselImagesClient;

    /**
     * 新增轮播图
     *
     * @param param 新增参数
     * @return 轮播图主键
     */
    @PostMapping("/carouselImages")
    public Long addCarouselImages(@RequestBody @Valid CarouselImagesModifyParam param) {
        return this.carouselImagesClient.addCarouselImages(param);
    }

    /**
     * 修改轮播图
     *
     * @param id    轮播图主键
     * @param param 修改参数
     */
    @PutMapping("/carouselImages/{id}")
    public void updateCarouselImages(@PathVariable("id") @Min(value = 1, message = "轮播图主键不能小于1") Long id,
                                     @RequestBody @Valid CarouselImagesModifyParam param) {
        this.carouselImagesClient.updateCarouselImages(id, param);
    }

    /**
     * 删除轮播图
     *
     * @param id 轮播图主键
     */
    @PutMapping("/carouselImages/delete/{id}")
    public void deleteCarouselImages(@PathVariable("id") @Min(value = 1, message = "轮播图主键不能小于1") Long id) {
        this.carouselImagesClient.deleteCarouselImages(id);
    }

    /**
     * 查询轮播图分页
     *
     * @param param 查询参数
     * @return 轮播图分页信息
     */
    @GetMapping("/carouselImages/paging")
    public Pagination<CarouselImagesDTO> getCarouselImagesPaging(@Valid CarouselImagesPagingParam param) {
        return this.carouselImagesClient.getCarouselImagesPaging(param);
    }
}
