package com.chelvc.cloud.admin.controller;
import com.chelvc.cloud.vehicle.client.OrderReturnApplyClient;
import com.chelvc.cloud.vehicle.client.dto.OrderReturnApplyDTO;
import com.chelvc.cloud.vehicle.client.param.OrderReturnApplyModifyParam;
import com.chelvc.cloud.vehicle.client.param.OrderReturnApplyPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.Min;

/**
 * 订单退货申请接口
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class OmsOrderReturnApplyController {

    private final OrderReturnApplyClient omsOrderReturnApplyServico;

    /**
     * 新增订单退货申请
     * @param param
     * @return
     */
    @PostMapping("/omsOrderReturnApply/add")
    public Long add(@RequestBody @Valid OrderReturnApplyModifyParam param) {
        return omsOrderReturnApplyServico.add(param);
    }

    /**
     * 修改订单退货申请
     * @param param
     * @return
     */
    @PutMapping("/omsOrderReturnApply/update/{id}")
    public Long update(@PathVariable("id") @Min(value = 1, message = "主键不能小于1") Long id, @RequestBody @Valid OrderReturnApplyModifyParam param) {
        return omsOrderReturnApplyServico.update(id,param);
    }

    /**
     * 订单退货申请分页查询
     * @param param
     * @return
     */
    @GetMapping("/omsOrderReturnApply/paging")
    public Pagination<OrderReturnApplyDTO> paging(@Valid OrderReturnApplyPagingParam param) {
        return omsOrderReturnApplyServico.paging(param);
    }



    /**
     * 订单退货申请查询详情
     * @param id
     * @return
     */
    @GetMapping("/omsOrderReturnApply/getDetail/{id}")
    public OrderReturnApplyDTO getDetail(@PathVariable("id") @Min(value = 1, message = "通知配置主键不能小于1")Long id) {
        return omsOrderReturnApplyServico.getDetail(id);
    }

    /**
     * 删除订单退货申请
     * @param id
     * @return
     */
    @GetMapping("/omsOrderReturnApply/delete/{id}")
    public void delete(@PathVariable("id") @Min(value = 1, message = "主键不能小于1")Long id) {
        omsOrderReturnApplyServico.delete(id);
    }

}
