package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

import com.chelvc.cloud.vehicle.client.ProfitRatioConfigClient;
import com.chelvc.cloud.vehicle.client.dto.ProfitRatioConfigDTO;
import com.chelvc.cloud.vehicle.client.param.AddProfitRatioConfigParams;
import com.chelvc.cloud.vehicle.client.param.EditProfitRatioConfigParams;
import com.chelvc.cloud.vehicle.client.param.QueryProfitRatioConfigParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 分佣比例配置管理接口
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class ProfitRatioConfigController {
    private final ProfitRatioConfigClient profitRatioConfigClient;

    /**
     * 新增
     *
     * @param param 新增参数
     */
    @PostMapping("/profit-ratio/add")
    public void add(@RequestBody @Valid AddProfitRatioConfigParams param) {
        param.setUserId(SessionContextHolder.getId());
        this.profitRatioConfigClient.add(param);
    }

    /**
     * 修改
     *
     * @param param 修改参数
     */
    @PutMapping("/profit-ratio/edit")
    public void edit(@RequestBody @Valid EditProfitRatioConfigParams param) {
        param.setUserId(SessionContextHolder.getId());
        this.profitRatioConfigClient.edit(param);
    }

    /**
     * 删除
     *
     * @param id
     */
    @DeleteMapping("/profit-ratio/del/{id}")
    public void delete(@NotNull(message = "主键不能为空") @PathVariable Long id) {
        this.profitRatioConfigClient.delete(id, SessionContextHolder.getId());
    }

    /**
     * 查询列表
     *
     * @param param
     * @author igl
     * @date 2024/2/23 17:25
     */
    @GetMapping("/profit-ratio/list")
    public Pagination<ProfitRatioConfigDTO> list(QueryProfitRatioConfigParam param) {
        return this.profitRatioConfigClient.queryPageList(param);
    }
}
